@@ -90,9 +90,15 @@ public abstract class AbstractOAuthTokenAction extends AbstractOAuthAJAXActionSe
         /*
          * Check for reported oauth problems
          */
-        String oauth_problem = request.getParameter(OAuthConstants.URLPARAM_OAUTH_PROBLEM);
-        if(!Strings.isEmpty(oauth_problem)) {
-            throw fromOauthProblem(oauth_problem, request, service);
+        {
+            String oauth_problem = request.getParameter(OAuthConstants.URLPARAM_OAUTH_PROBLEM);
+            if(!Strings.isEmpty(oauth_problem)) {
+                throw fromOauthProblem(oauth_problem, request, service);
+            }
+            oauth_problem = request.getParameter(OAuthConstants.URLPARAM_ERROR);
+            if(!Strings.isEmpty(oauth_problem)) {
+                throw fromOauthProblem(oauth_problem, request, service);
+            }
         }
 
         String oauthToken = request.getParameter(OAuthConstants.URLPARAM_OAUTH_TOKEN);
@@ -130,7 +136,7 @@ public abstract class AbstractOAuthTokenAction extends AbstractOAuthAJAXActionSe
         final Map<String, Object> arguments = new HashMap<String, Object>(3);
         {
             final String displayName = request.getParameter(AccountField.DISPLAY_NAME.getName());
-            if (isEmpty(displayName)) {
+            if (Strings.isEmpty(displayName)) {
                 throw AjaxExceptionCodes.MISSING_PARAMETER.create(AccountField.DISPLAY_NAME.getName());
             }
             arguments.put(OAuthConstants.ARGUMENT_DISPLAY_NAME, displayName);
@@ -166,18 +172,6 @@ public abstract class AbstractOAuthTokenAction extends AbstractOAuthAJAXActionSe
         return sb.toString();
 	}
 
-	private static boolean isEmpty(final String string) {
-        if (null == string) {
-            return true;
-        }
-        final int len = string.length();
-        boolean isWhitespace = true;
-        for (int i = 0; isWhitespace && i < len; i++) {
-            isWhitespace = com.openexchange.java.Strings.isWhitespace(string.charAt(i));
-        }
-        return isWhitespace;
-    }
-
     /**
      * Create the correct {@link OAuthExceptionCode} by mapping the incoming problem against the known problems in {@link OAuthConstants}
      *
@@ -216,6 +210,9 @@ public abstract class AbstractOAuthTokenAction extends AbstractOAuthAJAXActionSe
         if (OAUTH_PROBLEM_PERMISSION_DENIED.equals(oauth_problem)) {
             return OAuthExceptionCodes.OAUTH_PROBLEM_PERMISSION_DENIED.create();
         }
+        if (OAUTH_PROBLEM_ACCESS_DENIED.equals(oauth_problem)) {
+            return OAuthExceptionCodes.OAUTH_PROBLEM_ACCESS_DENIED.create();
+        }
         if (OAUTH_PROBLEM_PERMISSION_UNKNOWN.equals(oauth_problem)) {
             return OAuthExceptionCodes.OAUTH_PROBLEM_PERMISSION_UNKNOWN.create();
         }
