@@ -55,7 +55,6 @@ import javax.servlet.http.HttpServletResponse;
 import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
-import com.openexchange.ajax.requesthandler.AJAXRequestDataTools;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.ajax.requesthandler.DispatcherNotes;
 import com.openexchange.documentation.RequestMethod;
@@ -68,10 +67,8 @@ import com.openexchange.oauth.OAuthInteractionType;
 import com.openexchange.oauth.OAuthService;
 import com.openexchange.oauth.OAuthServiceMetaData;
 import com.openexchange.oauth.OAuthServiceMetaDataRegistry;
-import com.openexchange.oauth.OAuthUtilizerCreator;
 import com.openexchange.oauth.json.oauthaccount.AccountField;
 import com.openexchange.oauth.json.oauthaccount.AccountWriter;
-import com.openexchange.oauth.json.osgi.UtilizerRegistry;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
 import com.openexchange.tools.servlet.http.Tools;
 import com.openexchange.tools.session.ServerSession;
@@ -135,17 +132,6 @@ public final class CreateAction extends AbstractOAuthTokenAction {
                 }
             }
 
-            // Shall we create an account utilizer?
-            // TODO: Change default to false once appropriate file storage account managing is supported by clients
-            if (AJAXRequestDataTools.parseBoolParameter("auto_create", request, true)) {
-                UtilizerRegistry registry = UtilizerRegistry.getInstance();
-                if (null != registry) {
-                    for (OAuthUtilizerCreator creator : registry.getCreatorsFor(service.getAPI())) {
-                        creator.createUtilizer(newAccount, session);
-                    }
-                }
-            }
-
             // Write as JSON
             final JSONObject jsonAccount = AccountWriter.write(newAccount);
 
