@@ -49,49 +49,36 @@
 
 package com.openexchange.oauth.yahoo.internal;
 
-import java.util.HashMap;
-import java.util.Map;
+import java.util.Collection;
+import java.util.Collections;
 import org.scribe.builder.api.Api;
 import org.scribe.builder.api.YahooApi;
-import com.openexchange.config.ConfigurationService;
-import com.openexchange.config.Reloadable;
 import com.openexchange.http.deferrer.DeferringURLService;
 import com.openexchange.oauth.API;
-import com.openexchange.oauth.AbstractOAuthServiceMetaData;
+import com.openexchange.oauth.AbstractScribeAwareOAuthServiceMetaData;
+import com.openexchange.server.ServiceLookup;
+import com.openexchange.session.Session;
 
 /**
  * {@link OAuthServiceMetaDataYahooImpl}
  *
  * @author <a href="mailto:karsten.will@open-xchange.com">Karsten Will</a>
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
+ * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
  */
-public class OAuthServiceMetaDataYahooImpl extends AbstractOAuthServiceMetaData implements com.openexchange.oauth.ScribeAware, Reloadable {
+public class OAuthServiceMetaDataYahooImpl extends AbstractScribeAwareOAuthServiceMetaData {
 
-    private static final String API_KEY = "com.openexchange.oauth.yahoo.apiKey";
-
-    private static final String API_SECRET = "com.openexchange.oauth.yahoo.apiSecret";
-
-    private static final String[] PROPERTIES = new String[] {API_KEY, API_SECRET};
-
-    private final DeferringURLService deferrer;
-
-    public OAuthServiceMetaDataYahooImpl(DeferringURLService deferrer) {
-        super();
-        setId("com.openexchange.oauth.yahoo");
-        setAPIKeyName(API_KEY);
-        setAPISecretName(API_SECRET);
-        setDisplayName("Yahoo");
-        this.deferrer = deferrer;
+    public OAuthServiceMetaDataYahooImpl(ServiceLookup services) {
+        super(services, "com.openexchange.oauth.yahoo", "Yahoo");
     }
 
     @Override
-    public boolean registerTokenBasedDeferrer() {
-        return true;
-    }
-
-    @Override
-    public boolean needsRequestToken() {
-        return true;
+    public String modifyCallbackURL(String callbackUrl, String currentHost, Session session) {
+        DeferringURLService deferrer = services.getService(DeferringURLService.class);
+        if (deferrer == null) {
+            return callbackUrl;
+        }
+        return deferrer.getDeferredURL(callbackUrl, session.getUserId(), session.getContextId());
     }
 
     @Override
@@ -105,25 +92,12 @@ public class OAuthServiceMetaDataYahooImpl extends AbstractOAuthServiceMetaData
     }
 
     @Override
-    public void reloadConfiguration(ConfigurationService configService) {
-        String apiKey = configService.getProperty(apiKeyName);
-        String secretKey = configService.getProperty(apiSecretName);
-
-        if (apiKey.isEmpty()) {
-            throw new IllegalStateException("Missing following property in configuration: " + apiKeyName);
-        }
-        if (secretKey.isEmpty()) {
-            throw new IllegalStateException("Missing following property in configuration: " + apiSecretName);
-        }
-
-        this.apiKey = apiKey;
-        this.apiSecret = secretKey;
+    protected String getPropertyId() {
+        return "yahoo";
     }
 
     @Override
-    public Map<String, String[]> getConfigFileNames() {
-        Map<String, String[]> map = new HashMap<String, String[]>(1);
-        map.put("yahoooauth.properties", PROPERTIES);
-        return map;
+    protected Collection<OAuthPropertyID> getExtraPropertyNames() {
+        return Collections.emptyList();
     }
 }
