@@ -53,10 +53,6 @@ package com.openexchange.oauth;
  * {@link API} - An enumeration for available APIs.
  */
 public enum API {
-    /**
-     * Facebook
-     */
-    FACEBOOK,
     /**
      * Twitter
      */
